Write class

Constructors

Write({int? interval, int? delay, Map<String, dynamic>? sendRule, String? name, String? sourceType, String? sourceWriteFormat, Map<String, dynamic>? sourceParams, String? sourceUrl})
Write.fromJson(Map<String, dynamic> json)

Properties

delay ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interval ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendRule ↔ Map<String, dynamic>?
getter/setter pair
sourceParams ↔ Map<String, dynamic>?
getter/setter pair
sourceType ↔ String?
getter/setter pair
sourceUrl ↔ String?
getter/setter pair
sourceWriteFormat ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited