Machine class

Inheritance

Constructors

Machine({Collector? collector, Company? company, bool? deleted, String? id, dynamic linkedMachine, String? name, List<String>? tags})
Machine.fromJson(Map<String, dynamic> json)

Properties

collector ↔ Collector?
getter/setter pair
company ↔ Company?
getter/setter pair
deleted ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
linkedMachine ↔ dynamic
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<String>?
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited